from mercurial.hgweb.hgwebdir_mod import hgwebdir
from mercurial.hgweb.hgweb_mod import hgweb

def hgwebdir_app_factory(global_config, **local_conf):
    return hgwebdir(local_conf.get('webdir.conf', None))

def hgweb_app_factory(global_config, **local_conf):
    return hgweb(local_conf.get("repository", '.'))



#!/usr/bin/python
try:
    import setuptools
except ImportError:

    import ez_setup
    ez_setup.use_setuptools()

from setuptools import setup, find_packages
import sys, os

setup(
    name='hgpasteapp',
    version='0.1',
    description='Simple wrapper to hgweb that has paster app_factory entrypoints.',
    author='Maries Ionel Cristian',
    author_email='ionel.mc@gmail.com',
    packages=['hgpasteapp'],
    zip_safe=True,
    classifiers=[
    ],
    entry_points={
        'paste.app_factory': [
            'hgweb=hgpasteapp:hgweb_app_factory',
            'hgwebdir=hgpasteapp:hgwebdir_app_factory',
        ],
    },
    install_requires = ["mercurial"]
)
